@@ -589,10 +589,6 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
                 reset_cache=True,
             )
 
-            # Note if no data has been found
-            if not data_returned:
-                self.error_or_status_messages.value = "No structures found!"
-
         except QueryError:
             self.structure_drop.reset()
             self.structure_page_chooser.reset()
