@@ -1,5 +1,5 @@
 import os
-from typing import List, Tuple, Union
+from typing import Dict, List, Tuple, Union
 import urllib.parse
 
 try:
@@ -50,10 +50,18 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
     HINT = {"provider": "Select a provider", "child_dbs": "Select a database"}
     INITIAL_CHILD_DBS = [("No provider chosen", None)]
 
-    def __init__(self, child_db_limit: int = None, **kwargs):
+    def __init__(
+        self,
+        child_db_limit: int = None,
+        disable_providers: List[str] = None,
+        skip_providers: List[str] = None,
+        skip_databases: Dict[str, List[str]] = None,
+        **kwargs,
+    ):
         self.child_db_limit = (
             child_db_limit if child_db_limit and child_db_limit > 0 else 10
         )
+        self.skip_child_dbs = skip_databases or {}
         self.offset = 0
         self.number = 1
         self.__perform_query = True
@@ -61,10 +69,10 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
 
         self.debug = bool(os.environ.get("OPTIMADE_CLIENT_DEBUG", None))
 
-        dropdown_layout = ipw.Layout(width="auto")
-
         providers = []
-        providers, invalid_providers = get_list_of_valid_providers()
+        providers, invalid_providers = get_list_of_valid_providers(
+            disable_providers=disable_providers, skip_providers=skip_providers
+        )
         providers.insert(0, (self.HINT["provider"], None))
         if self.debug:
             from optimade_client.utils import VERSION_PARTS
@@ -83,12 +91,16 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
         self.providers = DropdownExtended(
             options=providers,
             disabled_options=invalid_providers,
-            layout=dropdown_layout,
+            layout=ipw.Layout(width="auto"),
         )
+
+        self.show_child_dbs = ipw.Layout(width="auto", display="none")
         self.child_dbs = ipw.Dropdown(
-            options=self.INITIAL_CHILD_DBS, layout=dropdown_layout, disabled=True
+            options=self.INITIAL_CHILD_DBS, layout=self.show_child_dbs
+        )
+        self.page_chooser = ResultsPageChooser(
+            page_limit=self.child_db_limit, layout=self.show_child_dbs
         )
-        self.page_chooser = ResultsPageChooser(self.child_db_limit, **kwargs)
 
         self.providers.observe(self._observe_providers, names="index")
         self.child_dbs.observe(self._observe_child_dbs, names="index")
@@ -111,13 +123,13 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
     def freeze(self):
         """Disable widget"""
         self.providers.disabled = True
-        self.child_dbs.disabled = True
+        self.show_child_dbs.display = "none"
         self.page_chooser.freeze()
 
     def unfreeze(self):
         """Activate widget (in its current state)"""
         self.providers.disabled = False
-        self.child_dbs.disabled = False
+        self.show_child_dbs.display = None
         self.page_chooser.unfreeze()
 
     def reset(self):
@@ -126,20 +138,20 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
         self.offset = 0
         self.number = 1
 
-        self.providers.index = 0
         self.providers.disabled = False
+        self.providers.index = 0
 
+        self.show_child_dbs.display = "none"
         self.child_dbs.options = self.INITIAL_CHILD_DBS
-        self.child_dbs.disabled = True
 
     def _observe_providers(self, change: dict):
         """Update child database dropdown upon changing provider"""
         index = change["new"]
-        self.child_dbs.disabled = True
+        self.show_child_dbs.display = "none"
         self.provider = self.providers.value
         if index is None or self.providers.value is None:
+            self.show_child_dbs.display = "none"
             self.child_dbs.options = self.INITIAL_CHILD_DBS
-            self.child_dbs.disabled = True
             self.providers.index = 0
             self.child_dbs.index = 0
         else:
@@ -149,13 +161,13 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
                 # or we have failed to retrieve any implementations.
                 # Automatically choose the 1 implementation (if there),
                 # while otherwise keeping the dropdown disabled.
-                self.child_dbs.disabled = True
+                self.show_child_dbs.display = "none"
                 try:
                     self.child_dbs.index = 1
                 except IndexError:
                     pass
             else:
-                self.child_dbs.disabled = False
+                self.show_child_dbs.display = None
 
     def _observe_child_dbs(self, change):
         """Update database traitlet with base URL for chosen child database"""
@@ -210,7 +222,8 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
                 while True:
                     # Update list of structures in dropdown widget
                     exclude_child_dbs, final_child_dbs = self._update_child_dbs(
-                        child_dbs
+                        data=child_dbs,
+                        skip_dbs=self.skip_child_dbs.get(self.provider.name, []),
                     )
 
                     LOGGER.debug("Exclude child DBs: %r", exclude_child_dbs)
@@ -265,8 +278,8 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
                     self.providers.index,
                     self.providers.value,
                 )
+                self.show_child_dbs.display = "none"
                 self.child_dbs.options = self.INITIAL_CHILD_DBS
-                self.child_dbs.disabled = True
 
         else:
             self.unfreeze()
@@ -283,16 +296,24 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
             self.child_dbs.index = 0
 
     @staticmethod
-    def _update_child_dbs(data: List[dict]) -> Tuple[List[str], List[LinksResource]]:
+    def _update_child_dbs(
+        data: List[dict], skip_dbs: List[str] = None
+    ) -> Tuple[List[str], List[LinksResource]]:
         """Update child DB dropdown from response data"""
         child_dbs = []
         exclude_dbs = []
+        skip_dbs = skip_dbs or []
 
         for entry in data:
             child_db = update_old_links_resources(entry)
             if child_db is None:
                 continue
 
+            # Skip if desired by user
+            if child_db.id in skip_dbs:
+                exclude_dbs.append(child_db.id)
+                continue
+
             attributes = child_db.attributes
 
             # Skip if not a 'child' link_type database
@@ -391,7 +412,7 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
 
             data_returned = self.page_chooser.data_returned
             while True:
-                # Update list of structures in dropdown widget
+                # Update list of child DBs in dropdown widget
                 exclude_child_dbs, final_child_dbs = self._update_child_dbs(child_dbs)
 
                 data_returned -= len(exclude_child_dbs)
@@ -431,8 +452,8 @@ class ProviderImplementationChooser(  # pylint: disable=too-many-instance-attrib
                     self.providers.index,
                     self.providers.value,
                 )
+                self.show_child_dbs.display = "none"
                 self.child_dbs.options = self.INITIAL_CHILD_DBS
-                self.child_dbs.disabled = True
 
         else:
             self.unfreeze()
