@@ -1,5 +1,6 @@
 from collections import OrderedDict
 from enum import Enum, EnumMeta
+import os
 from pathlib import Path
 import re
 from typing import Tuple, List, Union, Iterable
@@ -61,6 +62,18 @@ SESSION.mount("https://", SESSION_ADAPTER)
 SESSION.mount("http://localhost", SESSION_ADAPTER_DEBUG)
 SESSION.mount("http://127.0.0.1", SESSION_ADAPTER_DEBUG)
 
+try:
+    DEVELOPMENT_MODE = bool(int(os.getenv("OPTIMADE_CLIENT_DEVELOPMENT_MODE", "0")))
+except ValueError:
+    LOGGER.debug(
+        (
+            "OPTIMADE_CLIENT_DEVELOPMENT_MODE found, but cannot be parsed as a bool of an int. "
+            "Setting it to False. Found value: %s"
+        ),
+        os.getenv("OPTIMADE_CLIENT_DEVELOPMENT_MODE"),
+    )
+    DEVELOPMENT_MODE = False
+
 
 class DefaultingEnum(EnumMeta):
     """Override __getitem__()"""
@@ -222,7 +235,7 @@ def update_local_providers_json(response: dict) -> None:
 def fetch_providers(providers_urls: Union[str, List[str]] = None) -> list:
     """Fetch OPTIMADE database providers (from Materials-Consortia)
 
-    :param providers_urls: String pr list of strings with versioned base URL(s)
+    :param providers_urls: String or list of strings with versioned base URL(s)
         to Materials-Consortia providers database
     """
     if providers_urls and not isinstance(providers_urls, (list, str)):
@@ -374,9 +387,9 @@ def get_versioned_base_url(  # pylint: disable=too-many-branches
     return ""
 
 
-def get_list_of_valid_providers() -> Tuple[
-    List[Tuple[str, LinksResourceAttributes]], List[str]
-]:
+def get_list_of_valid_providers(  # pylint: disable=too-many-branches
+    disable_providers: List[str] = None, skip_providers: List[str] = None
+) -> Tuple[List[Tuple[str, LinksResourceAttributes]], List[str]]:
     """Get curated list of database providers
 
     Return formatted list of tuples to use with a dropdown-widget.
@@ -384,22 +397,19 @@ def get_list_of_valid_providers() -> Tuple[
     providers = fetch_providers()
     res = []
     invalid_providers = []
+    disable_providers = disable_providers or []
+    skip_providers = skip_providers or ["exmpl", "optimade", "aiida"]
 
     for entry in providers:
         provider = LinksResource(**entry)
 
-        # Skip if "exmpl", "optimade" or "aiida"
-        if provider.id in ["exmpl", "optimade", "aiida"]:
+        if provider.id in skip_providers:
             LOGGER.debug("Skipping provider: %s", provider)
             continue
 
         attributes = provider.attributes
 
-        # NOTE: Temporarily disable providers NOT properly satisfying the OPTIMADE specification
-        # Follow issue #206: https://github.com/CasperWA/voila-optimade-client/issues/206
-        # For omdb: Follow issue #246: https://github.com/CasperWA/voila-optimade-client/issues/246
-        temp_disable_providers = ["cod", "tcod", "nmd", "omdb", "oqmd"]
-        if provider.id in temp_disable_providers:
+        if provider.id in disable_providers:
             LOGGER.debug("Temporarily disabling provider: %s", str(provider))
             invalid_providers.append((attributes.name, attributes))
             continue
@@ -420,6 +430,27 @@ def get_list_of_valid_providers() -> Tuple[
             invalid_providers.append((attributes.name, attributes))
             continue
 
+        # Use development servers for providers if desired and available
+        known_development_providers = [
+            ("mcloud", "https://dev-www.materialscloud.org/optimade")
+        ]
+        if DEVELOPMENT_MODE:
+            for provider_id, development_base_url in known_development_providers:
+                LOGGER.debug(
+                    "Setting base URL for %s to their development server", provider_id
+                )
+                if isinstance(attributes.base_url, dict):
+                    attributes.base_url["href"] = development_base_url
+                elif isinstance(attributes.base_url, Link):
+                    attributes.base_url.href = development_base_url
+                elif isinstance(attributes.base_url, (AnyUrl, str)):
+                    attributes.base_url = development_base_url
+                else:
+                    raise TypeError(
+                        "base_url not found to be a valid type. Must be either an optimade.models."
+                        f"Link or a dict. Found type: {type(attributes.base_url)}"
+                    )
+
         versioned_base_url = get_versioned_base_url(attributes.base_url)
         if versioned_base_url:
             attributes.base_url = versioned_base_url
